@@ -144,6 +144,47 @@ class DA_BERT_ML(Precooked):
                                             'learning_rate': 0.0001},
                          tokenizer_parameters = {'do_lower_case' : True})
 
+class DA_BERT_ML_16BIT(Precooked):
+    """NERDA [Multilingual BERT](https://huggingface.co/bert-base-multilingual-uncased) 
+    for Danish Finetuned on [DaNE data set](https://github.com/alexandrainst/danlp/blob/master/docs/docs/datasets.md#dane).
+    
+    Model uses 16 bit floating points.
+
+    Inherits from [NERDA.precooked.Precooked][].
+    
+    Examples:
+        >>> from NERDA.precooked import DA_BERT_ML()
+        >>> model = DA_BERT_ML()
+        >>> model.download_network()
+        >>> model.load_network()
+        >>> text = 'Jens Hansen har en bondegård'
+        >>> model.predict_text(text)
+        ([['Jens', 'Hansen', 'har', 'en', 'bondegård']], [['B-PER', 'I-PER', 'O', 'O', 'O']])
+    
+    """
+    def __init__(self) -> None:
+        """Initialize model"""
+        super().__init__(transformer = 'bert-base-multilingual-uncased',
+                         device = None,
+                         tag_scheme = [
+                            'B-PER',
+                            'I-PER', 
+                            'B-ORG', 
+                            'I-ORG', 
+                            'B-LOC', 
+                            'I-LOC', 
+                            'B-MISC', 
+                            'I-MISC'
+                            ],
+                         tag_outside = 'O',
+                         max_len = 128,
+                         dropout = 0.1,
+                         hyperparameters = {'epochs' : 4,
+                                            'warmup_steps' : 500,
+                                            'train_batch_size': 13,
+                                            'learning_rate': 0.0001},
+                         tokenizer_parameters = {'do_lower_case' : True})
+
 class DA_ELECTRA_DA(Precooked):
     """NERDA [Danish ELECTRA](https://huggingface.co/Maltehb/-l-ctra-danish-electra-small-uncased) 
     for Danish finetuned on [DaNE data set](https://github.com/alexandrainst/danlp/blob/master/docs/docs/datasets.md#dane).
